==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/serder/ImportMailboxItemsStatusImportedMailboxItemGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ImportMailboxItemsStatusImportedMailboxItemGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem> {

	public ImportMailboxItemsStatusImportedMailboxItemGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem ret = new net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem ret, JSONObject json) {

		JSONValue sourceJSON = json.get("source");
		ret.source =  GwtSerDerUtils.LONG.deserialize(sourceJSON);
		JSONValue destinationJSON = json.get("destination");
		ret.destination =  GwtSerDerUtils.LONG.deserialize(destinationJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem o, JSONObject ret) {

		ret.put("source",  GwtSerDerUtils.LONG.serialize( o.source ));
		ret.put("destination",  GwtSerDerUtils.LONG.serialize( o.destination ));
	}
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/backend/mail/api/gwt/serder/ImportMailboxItemsStatusImportedMailboxItemGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ImportMailboxItemsStatusImportedMailboxItemGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem> {

	public ImportMailboxItemsStatusImportedMailboxItemGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem ret = new net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem ret, JSONObject json) {
		JSONValue sourceJSON = json.get("source");
		ret.source =  GwtSerDerUtils.LONG.deserialize(sourceJSON);
		JSONValue destinationJSON = json.get("destination");
		ret.destination =  GwtSerDerUtils.LONG.deserialize(destinationJSON);
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("source")) {
			JSONValue sourceJSON = json.get("source");
			ret.source =  GwtSerDerUtils.LONG.deserialize(sourceJSON);
		}
		if (!childPropertiesToIgnore.contains("destination")) {
			JSONValue destinationJSON = json.get("destination");
			ret.destination =  GwtSerDerUtils.LONG.deserialize(destinationJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem o, JSONObject ret) {

		ret.put("source",  GwtSerDerUtils.LONG.serialize( o.source ));
		ret.put("destination",  GwtSerDerUtils.LONG.serialize( o.destination ));
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemsStatus.ImportedMailboxItem o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("source")) {
			ret.put("source",  GwtSerDerUtils.LONG.serialize( o.source ));
		}
		if (!childPropertiesToIgnore.contains("destination")) {
			ret.put("destination",  GwtSerDerUtils.LONG.serialize( o.destination ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
